package boshclient

import (
	"encoding/json"
	"fmt"
	"log"
	"net/http"
)

func (c *Client) HasChanges(deploymentName string, proposedManifest []byte, logger *log.Logger) (bool, error) {
	url := fmt.Sprintf("%s/deployments/%s/diff?redact=true", c.boshURL, deploymentName)

	request, err := preparePost(url, proposedManifest, "text/yaml")
	if err != nil {
		return false, err
	}

	var hasChanges bool
	err = c.getDeploymentResultFromBoshCheckingForErrors(request, http.StatusOK, extractHasChanges(&hasChanges), logger)

	return hasChanges, err
}

func extractHasChanges(hasChanges *bool) resultExtractor {
	return func(r *http.Response) error {
		var diff struct {
			Diff [][]interface{} `json:"diff"`
		}

		defer r.Body.Close()
		if err := json.NewDecoder(r.Body).Decode(&diff); err != nil {
			return err
		}

		*hasChanges = len(diff.Diff) > 0

		return nil
	}
}
